@@ -1029,9 +1029,13 @@ class Builder(Update):
         dv = self.clVars.Get('builder.cl_builder_linux_datavars')
         if dv:
             deo = dv.Get('cl_emerge_default_opts')
+            if dv.GetBool('update.cl_update_with_bdeps_set'):
+                bdeps = " --with-bdeps=y"
+            else:
+                bdeps = " --with-bdeps=n"
+            return deo + bdeps
         else:
-            deo = super(Builder, self).get_default_emerge_opts()
-        return deo
+            return super(Builder, self).get_default_emerge_opts()
 
     def emerge(self, builder_path, use, *params):
         """
